@@ -221,6 +221,14 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         assertTrue(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
+    @Test
+    public void testIsSuppressedAfterEventStart2() throws Exception {
+        populateHolder("check", 100, 100, 350, 350);
+        final AuditEvent event = createAuditEvent("check", 100, 0);
+
+        assertTrue(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
+    }
+
     @Test
     public void testIsSuppressedWithAllArgument() throws Exception {
         populateHolder("all", 100, 100, 350, 350);
@@ -251,9 +259,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
     public void testAnnotationInTry() throws Exception {
         final Configuration checkConfig = createModuleConfig(SuppressWarningsHolder.class);
 
-        final String[] expected = {
-            "11: " + getCheckMessage(SuppressWarningsHolder.MSG_KEY),
-        };
+        final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, getPath("InputSuppressWarningsHolder2.java"), expected);
     }
@@ -379,6 +385,15 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         verify(checkConfig, getPath("InputSuppressWarningsHolder4.java"), expected);
     }
 
+    @Test
+    public void testSuppressWarningsAsAnnotationProperty() throws Exception {
+        final Configuration checkConfig = createModuleConfig(SuppressWarningsHolder.class);
+
+        final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
+
+        verify(checkConfig, getPath("InputSuppressWarningsHolder7.java"), expected);
+    }
+
     @Test
     @SuppressWarnings("unchecked")
     public void testClearState() throws Exception {
