@@ -78,21 +78,21 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STANDARD_JAVA_PACKAGE");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
-            "5: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
+            "5:1: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
                 "java.io.File.createTempFile"),
-            "8: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Button"),
-            "9: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Frame"),
-            "10: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Dialog"),
-            "11: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.color.ColorSpace"),
-            "12: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.event.ActionEvent"),
-            "13: " + getCheckMessage(MSG_ORDER, STD, SAME, "javax.swing.JComponent"),
-            "14: " + getCheckMessage(MSG_ORDER, STD, SAME, "javax.swing.JTable"),
-            "15: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.File"),
-            "16: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.IOException"),
-            "17: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.InputStream"),
-            "18: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.Reader"),
+            "8:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Button"),
+            "9:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Frame"),
+            "10:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.Dialog"),
+            "11:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.color.ColorSpace"),
+            "12:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.awt.event.ActionEvent"),
+            "13:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "javax.swing.JComponent"),
+            "14:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "javax.swing.JTable"),
+            "15:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.File"),
+            "16:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.IOException"),
+            "17:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.InputStream"),
+            "18:1: " + getCheckMessage(MSG_ORDER, STD, SAME, "java.io.Reader"),
         };
 
         verify(checkConfig, getPath("InputCustomImportOrderDefault.java"), expected);
@@ -111,17 +111,17 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###STANDARD_JAVA_PACKAGE###THIRD_PARTY_PACKAGE");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
-            "5: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
+            "5:1: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
                 "java.io.File.createTempFile"),
-            "10: " + getCheckMessage(MSG_LEX, "java.awt.Dialog", "java.awt.Frame"),
-            "15: " + getCheckMessage(MSG_LEX, "java.io.File", "javax.swing.JTable"),
-            "16: " + getCheckMessage(MSG_LEX, "java.io.IOException", "javax.swing.JTable"),
-            "17: " + getCheckMessage(MSG_LEX, "java.io.InputStream", "javax.swing.JTable"),
-            "18: " + getCheckMessage(MSG_LEX, "java.io.Reader", "javax.swing.JTable"),
-            "22: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.collect.*"),
-            "22: " + getCheckMessage(MSG_LEX, "com.google.common.collect.*",
+            "10:1: " + getCheckMessage(MSG_LEX, "java.awt.Dialog", "java.awt.Frame"),
+            "15:1: " + getCheckMessage(MSG_LEX, "java.io.File", "javax.swing.JTable"),
+            "16:1: " + getCheckMessage(MSG_LEX, "java.io.IOException", "javax.swing.JTable"),
+            "17:1: " + getCheckMessage(MSG_LEX, "java.io.InputStream", "javax.swing.JTable"),
+            "18:1: " + getCheckMessage(MSG_LEX, "java.io.Reader", "javax.swing.JTable"),
+            "22:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.collect.*"),
+            "22:1: " + getCheckMessage(MSG_LEX, "com.google.common.collect.*",
                 "com.puppycrawl.tools.*"),
         };
 
@@ -140,23 +140,35 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###STANDARD_JAVA_PACKAGE###THIRD_PARTY_PACKAGE###SAME_PACKAGE(3)");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
-            "5: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
+            "5:1: " + getCheckMessage(MSG_LEX, "java.awt.print.Paper.*",
                 "java.io.File.createTempFile"),
-            "10: " + getCheckMessage(MSG_LEX, "java.awt.Dialog", "java.awt.Frame"),
-            "15: " + getCheckMessage(MSG_LEX, "java.io.File", "javax.swing.JTable"),
-            "16: " + getCheckMessage(MSG_LEX, "java.io.IOException", "javax.swing.JTable"),
-            "17: " + getCheckMessage(MSG_LEX, "java.io.InputStream", "javax.swing.JTable"),
-            "18: " + getCheckMessage(MSG_LEX, "java.io.Reader", "javax.swing.JTable"),
-            "20: " + getCheckMessage(MSG_ORDER, SAME, THIRD, "com.puppycrawl.tools.*"),
-            "22: " + getCheckMessage(MSG_NONGROUP_IMPORT, "com.google.common.collect.*"),
-            "23: " + getCheckMessage(MSG_LINE_SEPARATOR, "org.junit.*"),
+            "10:1: " + getCheckMessage(MSG_LEX, "java.awt.Dialog", "java.awt.Frame"),
+            "15:1: " + getCheckMessage(MSG_LEX, "java.io.File", "javax.swing.JTable"),
+            "16:1: " + getCheckMessage(MSG_LEX, "java.io.IOException", "javax.swing.JTable"),
+            "17:1: " + getCheckMessage(MSG_LEX, "java.io.InputStream", "javax.swing.JTable"),
+            "18:1: " + getCheckMessage(MSG_LEX, "java.io.Reader", "javax.swing.JTable"),
+            "20:1: " + getCheckMessage(MSG_ORDER, SAME, THIRD, "com.puppycrawl.tools.*"),
+            "22:1: " + getCheckMessage(MSG_NONGROUP_IMPORT, "com.google.common.collect.*"),
+            "23:1: " + getCheckMessage(MSG_LINE_SEPARATOR, "org.junit.*"),
         };
 
         verify(checkConfig, getPath("InputCustomImportOrderDefault.java"), expected);
     }
 
+    @Test
+    public void testOrderRuleEmpty() throws Exception {
+        final DefaultConfiguration checkConfig =
+                createModuleConfig(CustomImportOrderCheck.class);
+        checkConfig.addAttribute("customImportOrderRules", "");
+        final String[] expected = {
+            "5:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.List"),
+        };
+
+        verify(checkConfig, getPath("InputCustomImportOrderEmptyRule.java"), expected);
+    }
+
     @Test
     public void testOrderRuleWithOneGroup() throws Exception {
         final DefaultConfiguration checkConfig =
@@ -166,20 +178,21 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STANDARD_JAVA_PACKAGE");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
-            "7: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.List"),
-            "7: " + getCheckMessage(MSG_LEX, "java.util.List", "javax.swing.WindowConstants.*"),
-            "8: " + getCheckMessage(MSG_LEX, "java.util.StringTokenizer",
+            "7:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.List"),
+            "7:1: " + getCheckMessage(MSG_LEX, "java.util.List", "javax.swing.WindowConstants.*"),
+            "8:1: " + getCheckMessage(MSG_LEX, "java.util.StringTokenizer",
                 "javax.swing.WindowConstants.*"),
-            "9: " + getCheckMessage(MSG_LEX, "java.util.*", "javax.swing.WindowConstants.*"),
-            "10: " + getCheckMessage(MSG_LEX, "java.util.concurrent.AbstractExecutorService",
+            "9:1: " + getCheckMessage(MSG_LEX, "java.util.*", "javax.swing.WindowConstants.*"),
+            "10:1: " + getCheckMessage(MSG_LEX, "java.util.concurrent.AbstractExecutorService",
                 "javax.swing.WindowConstants.*"),
-            "11: " + getCheckMessage(MSG_LEX, "java.util.concurrent.*",
+            "11:1: " + getCheckMessage(MSG_LEX, "java.util.concurrent.*",
                 "javax.swing.WindowConstants.*"),
-            "14: " + getCheckMessage(MSG_LEX, "com.*", "com.puppycrawl.tools.*"),
-            "16: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.base.*"),
-            "16: " + getCheckMessage(MSG_LEX, "com.google.common.base.*", "com.puppycrawl.tools.*"),
+            "14:1: " + getCheckMessage(MSG_LEX, "com.*", "com.puppycrawl.tools.*"),
+            "16:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.base.*"),
+            "16:1: " + getCheckMessage(MSG_LEX, "com.google.common.base.*",
+                "com.puppycrawl.tools.*"),
         };
 
         verify(checkConfig, getPath("InputCustomImportOrderDefault2.java"), expected);
@@ -194,15 +207,18 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###SAME_PACKAGE(3)");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_LEX, "java.util.*", "java.util.StringTokenizer"),
-            "6: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
-            "7: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.awt.Button.ABORT"),
-            "8: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "javax.swing.WindowConstants.*"),
-            "9: " + getCheckMessage(MSG_LEX, "com.puppycrawl.tools.*", "java.util.StringTokenizer"),
-            "10: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "5:1: " + getCheckMessage(MSG_LEX, "java.util.*", "java.util.StringTokenizer"),
+            "6:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
+            "7:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.awt.Button.ABORT"),
+            "8:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+                "javax.swing.WindowConstants.*"),
+            "9:1: " + getCheckMessage(MSG_LEX, "com.puppycrawl.tools.*",
+                "java.util.StringTokenizer"),
+            "10:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.AbstractExecutorService"),
-            "11: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.io.File.createTempFile"),
-            "12: " + getCheckMessage(MSG_LEX, "com.*", "java.util.StringTokenizer"),
+            "11:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+                "java.io.File.createTempFile"),
+            "12:1: " + getCheckMessage(MSG_LEX, "com.*", "java.util.StringTokenizer"),
         };
 
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderSamePackage.java"),
@@ -219,15 +235,18 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###SAME_PACKAGE(3)");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_LEX, "java.util.*", "java.util.StringTokenizer"),
-            "6: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
-            "7: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.awt.Button.ABORT"),
-            "8: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "javax.swing.WindowConstants.*"),
-            "9: " + getCheckMessage(MSG_LEX, "com.puppycrawl.tools.*", "java.util.StringTokenizer"),
-            "10: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "5:1: " + getCheckMessage(MSG_LEX, "java.util.*", "java.util.StringTokenizer"),
+            "6:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
+            "7:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.awt.Button.ABORT"),
+            "8:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+                "javax.swing.WindowConstants.*"),
+            "9:1: " + getCheckMessage(MSG_LEX, "com.puppycrawl.tools.*",
+                "java.util.StringTokenizer"),
+            "10:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.AbstractExecutorService"),
-            "11: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC, "java.io.File.createTempFile"),
-            "12: " + getCheckMessage(MSG_LEX, "com.*", "java.util.StringTokenizer"),
+            "11:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+                "java.io.File.createTempFile"),
+            "12:1: " + getCheckMessage(MSG_LEX, "com.*", "java.util.StringTokenizer"),
         };
 
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderSamePackage.java"),
@@ -243,9 +262,9 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
                 "STATIC###STANDARD_JAVA_PACKAGE");
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.io.File.createTempFile",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.io.File.createTempFile",
                 "javax.swing.WindowConstants.*"),
-            "8: " + getCheckMessage(MSG_LEX, "com.*", "com.puppycrawl.tools.*"),
+            "8:1: " + getCheckMessage(MSG_LEX, "com.*", "com.puppycrawl.tools.*"),
         };
 
         verify(checkConfig, getPath("InputCustomImportOrder_NoSeparator.java"), expected);
@@ -275,7 +294,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "STATIC###SPECIAL_IMPORTS###THIRD_PARTY_PACKAGE###STANDARD_JAVA_PACKAGE");
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD, "org.w3c.dom.Node"),
+            "5:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD, "org.w3c.dom.Node"),
         };
 
         verify(checkConfig,
@@ -292,20 +311,20 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("sortImportsInGroupAlphabetically", "true");
 
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
+            "7:1: " + getCheckMessage(MSG_LEX, "java.awt.Button.ABORT",
                 "java.io.File.createTempFile"),
-            "10: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Button"),
-            "11: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Frame"),
-            "12: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Dialog"),
-            "13: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.event.ActionEvent"),
-            "14: " + getCheckMessage(MSG_ORDER, STD, THIRD, "javax.swing.JComponent"),
-            "15: " + getCheckMessage(MSG_ORDER, STD, THIRD, "javax.swing.JTable"),
-            "16: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.File"),
-            "17: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.IOException"),
-            "18: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.InputStream"),
-            "19: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.Reader"),
-            "23: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.*"),
-            "23: " + getCheckMessage(MSG_LEX, "com.google.common.*", "com.puppycrawl.tools.*"),
+            "10:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Button"),
+            "11:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Frame"),
+            "12:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.Dialog"),
+            "13:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.awt.event.ActionEvent"),
+            "14:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "javax.swing.JComponent"),
+            "15:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "javax.swing.JTable"),
+            "16:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.File"),
+            "17:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.IOException"),
+            "18:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.InputStream"),
+            "19:1: " + getCheckMessage(MSG_ORDER, STD, THIRD, "java.io.Reader"),
+            "23:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.*"),
+            "23:1: " + getCheckMessage(MSG_LEX, "com.google.common.*", "com.puppycrawl.tools.*"),
         };
 
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderDefaultPackage.java"),
@@ -334,7 +353,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STATIC###SPECIAL_IMPORTS");
         final String[] expected = {
-            "11: " + getCheckMessage(MSG_ORDER, THIRD, SPECIAL,
+            "11:1: " + getCheckMessage(MSG_ORDER, THIRD, SPECIAL,
                 "com.google.common.collect.HashMultimap"),
         };
 
@@ -351,7 +370,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
             "STANDARD_JAVA_PACKAGE###SPECIAL_IMPORTS");
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_LEX, "java.util.Map",
+            "4:1: " + getCheckMessage(MSG_LEX, "java.util.Map",
                 "java.util.Map.Entry"),
         };
 
@@ -369,7 +388,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
             "STANDARD_JAVA_PACKAGE###SPECIAL_IMPORTS###THIRD_PARTY_PACKAGE");
         final String[] expected = {
-            "8: " + getCheckMessage(MSG_ORDER, THIRD, SPECIAL,
+            "8:1: " + getCheckMessage(MSG_ORDER, THIRD, SPECIAL,
                 "com.google.common.annotations.Beta"),
         };
 
@@ -401,7 +420,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "STANDARD_JAVA_PACKAGE###THIRD_PARTY_PACKAGE");
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "5:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                     "com.puppycrawl.tools.checkstyle.checks.javadoc.AbstractJavadocCheck"),
         };
 
@@ -445,16 +464,16 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "SAME_PACKAGE(2)");
         final String[] expected = {
-            "8: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.*"),
-            "9: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.List"),
-            "10: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.StringTokenizer"),
-            "11: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
-            "12: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "8:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.*"),
+            "9:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.List"),
+            "10:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.StringTokenizer"),
+            "11:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
+            "12:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.AbstractExecutorService"),
-            "13: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "13:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.locks.LockSupport"),
-            "14: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.regex.Pattern"),
-            "15: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.regex.Matcher"),
+            "14:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.regex.Pattern"),
+            "15:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.regex.Matcher"),
             };
 
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderSamePackageDepth25.java"),
@@ -470,10 +489,10 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "SAME_PACKAGE(3)");
         final String[] expected = {
-            "11: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
-            "12: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "11:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME, "java.util.concurrent.*"),
+            "12:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.AbstractExecutorService"),
-            "13: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "13:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.locks.LockSupport"),
             };
 
@@ -490,7 +509,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("customImportOrderRules",
                 "SAME_PACKAGE(4)");
         final String[] expected = {
-            "13: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
+            "13:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SAME,
                 "java.util.concurrent.locks.LockSupport"),
             };
 
@@ -638,9 +657,9 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "8: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.awt.Button"),
-            "20: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.puppycrawl.tools.*"),
-            "22: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.collect.*"),
+            "8:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.awt.Button"),
+            "20:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.puppycrawl.tools.*"),
+            "22:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "com.google.common.collect.*"),
         };
         verify(checkConfig, getPath("InputCustomImportOrderDefault.java"), expected);
     }
@@ -656,19 +675,19 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
         checkConfig.addAttribute("thirdPartyPackageRegExp",
             "com.puppycrawl.tools.checkstyle.checks.javadoc.*Javadoc*");
         final String[] expected = {
-            "9: " + getCheckMessage(MSG_ORDER, THIRD, STD,
+            "9:1: " + getCheckMessage(MSG_ORDER, THIRD, STD,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocNodeImpl"),
-            "13: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "13:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.AbstractJavadocCheck"),
-            "19: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "19:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.InvalidJavadocTag"),
-            "21: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
+            "21:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.WriteTagCheck"),
-            "25: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL,
+            "25:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocTag"),
-            "26: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
+            "26:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocMethodCheck"),
-            "27: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
+            "27:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD,
                 "com.puppycrawl.tools.checkstyle.checks.javadoc.NonEmptyAtclauseDescriptionCheck"),
             };
 
@@ -721,6 +740,24 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
             expected);
     }
 
+    @Test
+    public void testMultiplePatternMultipleImportFirstPatternHasLaterPosition() throws Exception {
+        final DefaultConfiguration checkConfig =
+            createModuleConfig(CustomImportOrderCheck.class);
+        checkConfig.addAttribute("customImportOrderRules",
+                "SPECIAL_IMPORTS###STANDARD_JAVA_PACKAGE");
+        checkConfig.addAttribute("specialImportsRegExp", "Test");
+        checkConfig.addAttribute("standardPackageRegExp", "unit");
+
+        createChecker(checkConfig);
+        final String[] expected = {
+            "4:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "org.junit.Test"),
+        };
+        verify(checkConfig,
+            getPath("InputCustomImportOrder_MultiplePatternMultipleImport.java"),
+            expected);
+    }
+
     @Test
     public void testNoPackage() throws Exception {
         final DefaultConfiguration checkConfig =
@@ -732,10 +769,10 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.*"),
-            "7: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.HashMap"),
-            "11: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "javax.net.ServerSocketFactory"),
-            "14: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "javax.net.SocketFactory"),
+            "5:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.*"),
+            "7:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.HashMap"),
+            "11:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "javax.net.ServerSocketFactory"),
+            "14:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "javax.net.SocketFactory"),
         };
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderNoPackage.java"),
             expected);
@@ -752,10 +789,10 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "7:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "com.sun.accessibility.internal.resources.*"),
-            "11: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.Arrays"),
-            "19: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "11:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.Arrays"),
+            "19:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "org.apache.commons.beanutils.converters.ArrayConverter"),
         };
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderNoPackage2.java"),
@@ -774,11 +811,11 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "6: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "6:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "java.util.Map"),
-            "14: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "14:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "org.apache.*"),
-            "18: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "18:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "antlr.*"),
         };
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderNoPackage3.java"),
@@ -798,13 +835,13 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "1: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "1:112: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "java.util.Map"),
-            "2: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "2:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "com.google.common.annotations.Beta"),
-            "9: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "9:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "com.puppycrawl.tools.*"),
-            "13: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "13:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "antlr.*"),
         };
         verify(checkConfig, getPath("InputCustomImportOrderSingleLine.java"),
@@ -821,7 +858,7 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "2: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "2:118: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "java.util.Map"),
         };
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderSingleLine2.java"),
@@ -841,21 +878,21 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "8: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "8:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "javax.swing.WindowConstants.*"),
-            "11: " + getCheckMessage(MSG_LINE_SEPARATOR,
+            "11:1: " + getCheckMessage(MSG_LINE_SEPARATOR,
                 "java.awt.Button"),
-            "15: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "15:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "java.awt.Dialog"),
-            "21: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "21:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "com.google.common.*"),
-            "27: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "27:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "org.apache.commons.collections.*"),
-            "32: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "32:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "com.puppycrawl.tools.checkstyle.checks.imports.AbstractImportRule"),
-            "38: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "38:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "antlr.Token"),
-            "40: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "40:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "antlr.collections.AST"),
         };
         verify(checkConfig,
@@ -873,13 +910,13 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "5: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+            "5:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
                 "java.util.Collections.*"),
-            "6: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
+            "6:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STATIC,
                 "java.lang.String.CASE_INSENSITIVE_ORDER"),
-            "9: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
+            "9:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP,
                 "java.net.Socket"),
-            "9: " + getCheckMessage(MSG_LEX, "java.net.Socket",
+            "9:1: " + getCheckMessage(MSG_LEX, "java.net.Socket",
                 "java.util.*"),
         };
         verify(checkConfig, getNonCompilablePath("InputCustomImportOrderViolationsSameLine.java"),
@@ -898,12 +935,12 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "18: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.BitSet"),
-            "33: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.HashSet"),
-            "37: " + getCheckMessage(MSG_LINE_SEPARATOR, "org.apache.tools.ant.*"),
-            "42: " + getCheckMessage(MSG_LINE_SEPARATOR, "com.puppycrawl.tools.checkstyle.*"),
-            "46: " + getCheckMessage(MSG_LINE_SEPARATOR, "antlr.*"),
-            "49: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "antlr.Token"),
+            "18:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.BitSet"),
+            "33:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "java.util.HashSet"),
+            "37:1: " + getCheckMessage(MSG_LINE_SEPARATOR, "org.apache.tools.ant.*"),
+            "42:1: " + getCheckMessage(MSG_LINE_SEPARATOR, "com.puppycrawl.tools.checkstyle.*"),
+            "46:1: " + getCheckMessage(MSG_LINE_SEPARATOR, "antlr.*"),
+            "49:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "antlr.Token"),
         };
         verify(checkConfig, getPath("InputCustomImportOrderSpanMultipleLines.java"), expected);
     }
@@ -924,15 +961,15 @@ public class CustomImportOrderCheckTest extends AbstractModuleTestSupport {
 
         createChecker(checkConfig);
         final String[] expected = {
-            "9: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.awt.Button"),
-            "10: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.awt.Dialog"),
-            "11: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.io.InputStream"),
-            "13: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL, "javax.swing.JComponent"),
-            "14: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL, "javax.swing.JTable"),
-            "16: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD, "org.junit.Test"),
-            "17: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD,
+            "9:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.awt.Button"),
+            "10:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.awt.Dialog"),
+            "11:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, STD, "java.io.InputStream"),
+            "13:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL, "javax.swing.JComponent"),
+            "14:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, SPECIAL, "javax.swing.JTable"),
+            "16:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD, "org.junit.Test"),
+            "17:1: " + getCheckMessage(MSG_NONGROUP_EXPECTED, THIRD,
                 "org.powermock.api.mockito.PowerMockito"),
-            "21: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "sun.tools.java.ArrayType"),
+            "21:1: " + getCheckMessage(MSG_SEPARATED_IN_GROUP, "sun.tools.java.ArrayType"),
         };
         verify(checkConfig,
             getNonCompilablePath("InputCustomImportOrderEclipseDefaultPositive.java"), expected);
