@@ -268,7 +268,7 @@ public class XdocsPagesTest {
 
         for (Path path : XdocUtil.getXdocsConfigFilePaths(XdocUtil.getXdocsFilePaths())) {
             final String fileName = path.getFileName().toString();
-            if ("config_reporting.xml".equals(fileName)
+            if ("config_system_properties.xml".equals(fileName)
                     || "config_filefilters.xml".equals(fileName)
                     || "config_filters.xml".equals(fileName)) {
                 continue;
@@ -478,7 +478,7 @@ public class XdocsPagesTest {
         for (Path path : XdocUtil.getXdocsConfigFilePaths(XdocUtil.getXdocsFilePaths())) {
             final String fileName = path.getFileName().toString();
 
-            if ("config_reporting.xml".equals(fileName)) {
+            if ("config_system_properties.xml".equals(fileName)) {
                 continue;
             }
 
@@ -515,6 +515,7 @@ public class XdocsPagesTest {
 
     /**
      * Test contains asserts in callstack, but idea does not see them.
+     *
      * @noinspection JUnitTestMethodWithNoAssertions
      */
     @Test
@@ -868,8 +869,9 @@ public class XdocsPagesTest {
                         + "' should have the type for " + propertyName);
 
         if (expectedValue != null) {
-            final String actualValue = columns.get(3).getTextContent().replace("\n", "")
-                    .replace("\r", "").replaceAll(" +", " ").trim();
+            final String actualValue = columns.get(3).getTextContent().trim()
+                    .replaceAll("\\s+", " ")
+                    .replaceAll("\\s,", ",");
 
             assertEquals(expectedValue, actualValue,
                     fileName + " section '" + sectionName
@@ -882,14 +884,33 @@ public class XdocsPagesTest {
         assertEquals("tokens to check", columns.get(1).getTextContent(),
                 fileName + " section '" + sectionName
                         + "' should have the basic token description");
-        assertEquals("subset of tokens " + CheckUtil.getTokenText(check.getAcceptableTokens(),
+
+        final String acceptableTokenText = columns.get(2).getTextContent().trim();
+        assertEquals("subset of tokens "
+                        + CheckUtil.getTokenText(check.getAcceptableTokens(),
                 check.getRequiredTokens()),
-                columns.get(2).getTextContent().replaceAll("\\s+", " ").trim(),
-                fileName + " section '" + sectionName + "' should have all the acceptable tokens");
-        assertEquals(
-                CheckUtil.getTokenText(check.getDefaultTokens(), check.getRequiredTokens()),
-                columns.get(3).getTextContent().replaceAll("\\s+", " ").trim(),
+                acceptableTokenText
+                        .replaceAll("\\s+", " ")
+                        .replaceAll("\\s,", ",")
+                        .replaceAll("\\s\\.", "."),
+                fileName + " section '" + sectionName
+                        + "' should have all the acceptable tokens");
+        assertFalse(isInvalidTokenPunctuation(acceptableTokenText),
+                fileName + "'s acceptable token section: " + sectionName
+                        + "should have ',' & '.' at beginning of the next corresponding lines.");
+
+        final String defaultTokenText = columns.get(3).getTextContent().trim();
+        assertEquals(CheckUtil.getTokenText(check.getDefaultTokens(),
+                check.getRequiredTokens()),
+                defaultTokenText
+                        .replaceAll("\\s+", " ")
+                        .replaceAll("\\s,", ",")
+                        .replaceAll("\\s\\.", "."),
                 fileName + " section '" + sectionName + "' should have all the default tokens");
+        assertFalse(isInvalidTokenPunctuation(defaultTokenText),
+                fileName + "'s default token section: " + sectionName
+                        + "should have ',' & '.' at beginning of the next corresponding lines.");
+
     }
 
     private static void validatePropertySectionPropertyJavadocTokens(String fileName,
@@ -897,20 +918,43 @@ public class XdocsPagesTest {
         assertEquals("javadoc tokens to check",
                 columns.get(1).getTextContent(), fileName + " section '" + sectionName
                         + "' should have the basic token javadoc description");
+
+        final String acceptableTokenText = columns.get(2).getTextContent().trim();
         assertEquals("subset of javadoc tokens "
                         + CheckUtil.getJavadocTokenText(check.getAcceptableJavadocTokens(),
-                                check.getRequiredJavadocTokens()), columns.get(2).getTextContent()
-                        .replaceAll("\\s+", " ").trim(), fileName + " section '" + sectionName
-                                + "' should have all the acceptable javadoc tokens");
-        assertEquals(
-                CheckUtil.getJavadocTokenText(check.getDefaultJavadocTokens(),
-                        check.getRequiredJavadocTokens()), columns.get(3).getTextContent()
-                        .replaceAll("\\s+", " ").trim(), fileName + " section '" + sectionName
-                                + "' should have all the default javadoc tokens");
+                check.getRequiredJavadocTokens()),
+                acceptableTokenText
+                        .replaceAll("\\s+", " ")
+                        .replaceAll("\\s,", ",")
+                        .replaceAll("\\s\\.", "."),
+                fileName + " section '" + sectionName
+                        + "' should have all the acceptable javadoc tokens");
+        assertFalse(isInvalidTokenPunctuation(acceptableTokenText),
+                fileName + "'s acceptable javadoc token section: " + sectionName
+                        + "should have ',' & '.' at beginning of the next corresponding lines.");
+
+        final String defaultTokenText = columns.get(3).getTextContent().trim();
+        assertEquals(CheckUtil.getJavadocTokenText(check.getDefaultJavadocTokens(),
+                check.getRequiredJavadocTokens()),
+                defaultTokenText
+                        .replaceAll("\\s+", " ")
+                        .replaceAll("\\s,", ",")
+                        .replaceAll("\\s\\.", "."),
+                fileName + " section '" + sectionName
+                        + "' should have all the default javadoc tokens");
+        assertFalse(isInvalidTokenPunctuation(defaultTokenText),
+                fileName + "'s default javadoc token section: " + sectionName
+                        + "should have ',' & '.' at beginning of the next corresponding lines.");
+    }
+
+    private static boolean isInvalidTokenPunctuation(String tokenText) {
+        return Pattern.compile("\\w,").matcher(tokenText).find()
+                || Pattern.compile("\\w\\.").matcher(tokenText).find();
     }
 
     /**
      * Get's the name of the bean property's type for the class.
+     *
      * @param sectionName The name of the section/module being worked on.
      * @param fieldClass The bean property's type.
      * @param instance The class instance to work with.
@@ -937,11 +981,6 @@ public class XdocsPagesTest {
             // dynamic custom expression
             result = "Regular Expression";
         }
-        else if ("CustomImportOrder".equals(sectionName)
-                && "customImportOrderRules".equals(propertyName)) {
-            // specially separated list
-            result = "String";
-        }
         else if (fieldClass == boolean.class) {
             result = "Boolean";
         }
@@ -1048,6 +1087,7 @@ public class XdocsPagesTest {
 
     /**
      * Get's the name of the bean property's default value for the class.
+     *
      * @param sectionName The name of the section/module being worked on.
      * @param propertyName The property name to work with.
      * @param field The bean property's field.
@@ -1071,7 +1111,7 @@ public class XdocsPagesTest {
                 result = "default locale language for the Java Virtual Machine";
             }
             else if ("Checker".equals(sectionName) && "charset".equals(propertyName)) {
-                result = "System property \"file.encoding\"";
+                result = "UTF-8";
             }
             else if ("charset".equals(propertyName)) {
                 result = "the charset property of the parent Checker module";
@@ -1261,6 +1301,7 @@ public class XdocsPagesTest {
 
     /**
      * Checks if the given property is takes token names as a type.
+     *
      * @param sectionName The name of the section/module being worked on.
      * @param propertyName The property name to work with.
      * @return {@code true} if the property is takes token names as a type.
@@ -1571,6 +1612,7 @@ public class XdocsPagesTest {
             styleChecks.remove("BeforeExecutionExclusionFileFilter");
             styleChecks.remove("SuppressionFilter");
             styleChecks.remove("SuppressionXpathFilter");
+            styleChecks.remove("SuppressionXpathSingleFilter");
             styleChecks.remove("TreeWalker");
             styleChecks.remove("Checker");
 
