@@ -44,6 +44,9 @@ import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.checks.javadoc.AbstractJavadocCheck;
+import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocStyleCheck;
+import com.puppycrawl.tools.checkstyle.checks.javadoc.JavadocTypeCheck;
+import com.puppycrawl.tools.checkstyle.checks.javadoc.WriteTagCheck;
 import com.puppycrawl.tools.checkstyle.internal.utils.CheckUtil;
 
 public class XpathRegressionTest extends AbstractModuleTestSupport {
@@ -52,54 +55,17 @@ public class XpathRegressionTest extends AbstractModuleTestSupport {
     // till https://github.com/checkstyle/checkstyle/issues/5777
     public static final Set<String> INCOMPATIBLE_CHECK_NAMES =
         Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
-            "AnnotationLocation",
-            "AnnotationOnSameLine",
-            "AnnotationUseStyle",
-            "ArrayTrailingComma",
-            "AvoidEscapedUnicodeCharacters",
-            "AvoidStarImport",
-            "AvoidStaticImport",
-            "CommentsIndentation",
-            "CustomImportOrder",
-            "EmptyCatchBlock",
             "EmptyLineSeparator",
-            "FinalClass",
-            "IllegalCatch",
-            "ImportOrder",
             "Indentation",
-            "InterfaceIsType",
-            "InterfaceMemberImpliedModifier",
-            "InvalidJavadocPosition",
-            "JavadocContentLocation",
             "JavadocMethod",
-            "JavadocStyle",
-            "JavadocType",
-            "LambdaParameterName",
-            "MethodCount",
-            "MissingCtor",
-            "MissingJavadocMethod",
-            "MissingJavadocPackage",
             "MissingJavadocType",
-            "MissingOverride",
-            "MissingSwitchDefault",
-            "NeedBraces",
-            "NoClone",
-            "NoFinalizer",
-            "NoLineWrap",
-            "OneTopLevelClass",
-            "OuterTypeFilename",
-            "OverloadMethodsDeclarationOrder",
-            "PackageAnnotation",
-            "PackageDeclaration",
-            "Regexp",
-            "RegexpSinglelineJava",
-            "SuppressWarningsHolder",
+            "NoCodeInFile (reason is that AST is not generated for a file not containing code)",
+            "Regexp (reason is at  #7759)",
+            "RegexpSinglelineJava (reason is at  #7759)",
             "TodoComment",
             "TrailingComment",
-            "UncommentedMain",
             "UnnecessaryParentheses",
-            "VariableDeclarationUsageDistance",
-            "WriteTag"
+            "VariableDeclarationUsageDistance"
     )));
 
     // Javadoc checks are not compatible with SuppressionXpathFilter
@@ -110,12 +76,25 @@ public class XpathRegressionTest extends AbstractModuleTestSupport {
             Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
                     "AtclauseOrder",
                     "JavadocBlockTagLocation",
+                    "JavadocMissingWhitespaceAfterAsterisk",
                     "JavadocParagraph",
+                    "JavadocStyle",
                     "JavadocTagContinuationIndentation",
+                    "JavadocType",
                     "MissingDeprecated",
                     "NonEmptyAtclauseDescription",
                     "SingleLineJavadoc",
-                    "SummaryJavadoc"
+                    "SummaryJavadoc",
+                    "WriteTag"
+    )));
+
+    // Older regex-based checks that are under INCOMPATIBLE_JAVADOC_CHECK_NAMES
+    // but not subclasses of AbstractJavadocCheck.
+    private static final Set<Class<?>> REGEXP_JAVADOC_CHECKS =
+            Collections.unmodifiableSet(new HashSet<>(Arrays.asList(
+                    JavadocStyleCheck.class,
+                    JavadocTypeCheck.class,
+                    WriteTagCheck.class
     )));
 
     // Checks that allowed to have no XPath IT Regression Testing
@@ -179,6 +158,11 @@ public class XpathRegressionTest extends AbstractModuleTestSupport {
             "VisibilityModifier"
     ));
 
+    // Modules that will never have xpath support ever because they not report violations
+    private static final Set<String> NO_VIOLATION_MODULES = new HashSet<>(Collections.singletonList(
+            "SuppressWarningsHolder"
+    ));
+
     private static Set<String> simpleCheckNames;
     private static Map<String, String> allowedDirectoryAndChecks;
 
@@ -212,10 +196,13 @@ public class XpathRegressionTest extends AbstractModuleTestSupport {
 
     @Test
     public void validateIncompatibleJavadocCheckNames() throws IOException {
+        // subclasses of AbstractJavadocCheck
         final Set<Class<?>> abstractJavadocCheckNames = CheckUtil.getCheckstyleChecks()
                 .stream()
                 .filter(AbstractJavadocCheck.class::isAssignableFrom)
                 .collect(Collectors.toSet());
+        // add the extra checks
+        abstractJavadocCheckNames.addAll(REGEXP_JAVADOC_CHECKS);
         assertWithMessage("INCOMPATIBLE_JAVADOC_CHECK_NAMES should contains all descendants "
                     + "of AbstractJavadocCheck")
             .that(CheckUtil.getSimpleNames(abstractJavadocCheckNames))
@@ -257,7 +244,9 @@ public class XpathRegressionTest extends AbstractModuleTestSupport {
         final Set<String> allChecks = new HashSet<>(simpleCheckNames);
         allChecks.removeAll(INCOMPATIBLE_JAVADOC_CHECK_NAMES);
         allChecks.removeAll(INCOMPATIBLE_CHECK_NAMES);
+        allChecks.removeAll(Arrays.asList("Regexp", "RegexpSinglelineJava", "NoCodeInFile"));
         allChecks.removeAll(MISSING_CHECK_NAMES);
+        allChecks.removeAll(NO_VIOLATION_MODULES);
         allChecks.removeAll(compatibleChecks);
 
         assertTrue(allChecks.isEmpty(), "XpathRegressionTest is missing for ["
